==> easybuild-framework-4.6.0.tar.gz: easybuild-framework-4.6.0/easybuild/toolchains/linalg/flame.py <==
##
# Copyright 2012-2022 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Support for FLAME as toolchain linear algebra library.

:author: Stijn De Weirdt (Ghent University)
:author: Kenneth Hoste (Ghent University)
:author: Sebastian Achilles (Forschungszentrum Juelich GmbH)
"""

from easybuild.toolchains.linalg.lapack import Lapack


TC_CONSTANT_FLAME = 'FLAME'


class Flame(Lapack):
    """Less trivial module, provides FLAME support."""
    LAPACK_MODULE_NAME = ['libFLAME']  # + Lapack.LAPACK_MODULE_NAME  # no super()
    LAPACK_LIB = ['flame']  # + Lapack.LAPACK_LIB  # no super()
    LAPACK_FAMILY = TC_CONSTANT_FLAME

==> easybuild-framework-4.9.0.tar.gz: easybuild-framework-4.9.0/easybuild/toolchains/linalg/flame.py <==
##
# Copyright 2012-2023 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Support for FLAME as toolchain linear algebra library.

Authors:

* Stijn De Weirdt (Ghent University)
* Kenneth Hoste (Ghent University)
* Sebastian Achilles (Forschungszentrum Juelich GmbH)
"""

from easybuild.toolchains.linalg.lapack import Lapack


TC_CONSTANT_FLAME = 'FLAME'


class Flame(Lapack):
    """Less trivial module, provides FLAME support."""
    LAPACK_MODULE_NAME = ['libFLAME']  # + Lapack.LAPACK_MODULE_NAME  # no super()
    LAPACK_LIB = ['flame']  # + Lapack.LAPACK_LIB  # no super()
    LAPACK_FAMILY = TC_CONSTANT_FLAME
